date_picker/date_picker library
Classes
- SpinnerDatePicker
- Actual date picker widget
Enums
- DateOptions
- Options to show on date picker
- DaysOfWeek
- Days of the week mapped by their numbers
- MonthsOfYear
- Months mapped by their numbers
Constants
- itemBorderRadius → const BorderRadius
- Default borderRadius
- itemStyle → const TextStyle
- Default itemStyle
Properties
-
getAllMonths
→ List<
MonthsOfYear> -
Get all MonthsOfYear in a year
no setter
- itemUnderline → Container
-
Default itemUnderline
no setter
Functions
-
days(
{required int lastDayOfMonth}) → List< int> - Get the list of days in getLastDayOfMonth
-
getItems<
T> ({required List< T> items, required String label(T)}) → List<DropdownMenuItem< T> > - Get DropDown items
-
getLastDayOfMonth(
{required int year, required int month}) → int -
Get the last day in a
yearandmonth -
getNoOfDaysInMonth(
{required int year, required int month}) → int -
Get the number of days in a
yearandmonth -
onChangeDate(
{required DateTime currentDate, required StreamController< DateTime> dateStreamController, int? day, int? month, int? year}) → void - Callback for when any dropdown changes a date Handling date conflicts
-
totalYears(
{required int maxYear, required int minYear}) → int -
Get The number of years in a range from
minYeartomaxYear -
years(
{required int totalYears, required int minYear}) → List< int> -
Generate range of from
minYearuptototalYears