DaysOfWeek enum
Days of the week mapped by their numbers
Values
- monday → const DaysOfWeek
-
const DaysOfWeek(number: 1) - tuesday → const DaysOfWeek
-
const DaysOfWeek(number: 2) - wednesday → const DaysOfWeek
-
const DaysOfWeek(number: 3) - thursday → const DaysOfWeek
-
const DaysOfWeek(number: 4) - friday → const DaysOfWeek
-
const DaysOfWeek(number: 5) - saturday → const DaysOfWeek
-
const DaysOfWeek(number: 6) - sunday → const DaysOfWeek
-
const DaysOfWeek(number: 7)
Properties
- dayName → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - number → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
findByNumber(
int n) → DaysOfWeek?
Constants
-
values
→ const List<
DaysOfWeek> - A constant List of the values in this enum, in order of their declaration.